@@ -1,4 +1,5 @@
 #include "general.h"
+#include <pyogg/pyogg.h>
 #include <ogg/ogg.h>
 
 /*
@@ -8,22 +9,18 @@
  */
 
 /* Simple function to turn an object into an ogg_int64_t. Returns 0 on
- * an error, so you need to use PyErr_Occurred() after calling it.  It
- * DECREFS the argument in the function. */
+ * an error. Does not DECREF the argument */
 
-ogg_int64_t
-arg_to_64(PyObject *longobj)
+int
+arg_to_int64(PyObject *longobj, ogg_int64_t *val)
 {
-  ogg_int64_t val = 0;
-
   if(PyLong_Check(longobj))
-    val = PyLong_AsLongLong(longobj);
+    *val = PyLong_AsLongLong(longobj);
   else if (PyInt_Check(longobj))
-    val = PyInt_AsLong(longobj);
+    *val = PyInt_AsLong(longobj);
   else {
-    Py_DECREF(longobj);
     PyErr_SetString(PyExc_TypeError, "Argument must be int or long");
+    return 0;
   }
-  Py_DECREF(longobj);
-  return val;
+  return 1;
 }
